@@ -9,7 +9,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2018 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -537,7 +537,7 @@ eval(char const * expr)
         (void)span_quote(pzTemp);
         expr = shell_cmd(pzTemp);
         AGFREE(pzTemp);
-        res = scm_from_latin1_string((char *)expr);
+        res = AG_SCM_FROM_STR((char *)expr);
         AGFREE(expr);
         break;
 
@@ -550,7 +550,7 @@ eval(char const * expr)
         /* FALLTHROUGH */
 
     default:
-        res = scm_from_latin1_string((char *)expr);
+        res = AG_SCM_FROM_STR((char *)expr);
         if (allocated)
             AGFREE(expr);
     }
